@@ -1638,6 +1638,7 @@ EOH
         parent => 'interval',
         handler => {
             GET => 'handler_get_interval_eid',
+            DELETE => 'handler_delete_interval_eid',
         },
         acl_profile => 'active', 
         cli => 'interval eid $EID $TSRANGE',
@@ -1668,6 +1669,7 @@ EOH
         parent => 'interval',
         handler => {
             GET => 'handler_get_interval_eid',
+            DELETE => 'handler_delete_interval_eid',
         },
         acl_profile => 'active', 
         cli => 'interval eid $EID $TS DELTA $PSQLINT',
@@ -1886,6 +1888,7 @@ EOH
         parent => 'interval',
         handler => {
             GET => 'handler_get_interval_nick',
+            DELETE => 'handler_delete_interval_nick',
         },
         acl_profile => 'active', 
         cli => 'interval nick $NICK $TSRANGE',
@@ -1916,6 +1919,7 @@ EOH
         parent => 'interval',
         handler => {
             GET => 'handler_get_interval_nick',
+            DELETE => 'handler_delete_interval_nick',
         },
         acl_profile => 'active', 
         cli => 'interval nick $NICK $TS DELTA $PSQLINT',
@@ -1939,6 +1943,7 @@ EOH
         parent => 'interval',
         handler => {
             GET => 'handler_get_interval_self',
+            DELETE => 'handler_delete_interval_self',
         },
         acl_profile => 'inactive', 
         cli => 'interval self $TSRANGE',
@@ -1968,6 +1973,7 @@ EOH
         parent => 'interval',
         handler => {
             GET => 'handler_get_interval_self',
+            DELETE => 'handler_delete_interval_self',
         },
         acl_profile => 'active', 
         cli => 'INTERVAL SELF $TS DELTA $PSQLINT',
